@@ -130,26 +130,6 @@ class ResourceLocker:
         '''
         return filter(lambda_expression, self.all())
 
-    def get_lockable_resources(self, free_only=True, label_matches=None, name=None ):
-        '''
-        :param free_only:
-        :param label_matches:
-        :param name:
-        :return:
-        '''
-        # Lets first design the final endpoint:
-        final_endpoint = self.endpoints['resources'] + f'?free_only={str(free_only).lower()}&'
-        if label_matches:
-            final_endpoint = f"{final_endpoint}label_matches={label_matches}"
-        if name:
-            final_endpoint = f"{final_endpoint}name={name}"
-
-        req = requests.get(final_endpoint, headers=self.headers)
-        if req.status_code == 200:
-            # json.loads returns it to a dictionary
-            req_dict = json.loads(req.text.encode('utf8'))
-            return req_dict
-
     def abort_queue(self, queue_id, abort_msg=None):
         '''
         A method to send a POST request to abort the queue that was created, and expected
@@ -242,3 +222,41 @@ class ResourceLocker:
             else:
                 raise Exception("Timeout Reached! \n"
                                 f"Status of the queue is not {status}!")
+
+
+    def get_lockable_resources(self, free_only=True, label_matches=None, name=None):
+        # Lets first design the final endpoint:
+        final_endpoint = self.endpoints['resources'] + f'?free_only={str(free_only).lower()}&'
+        if label_matches:
+            final_endpoint = f"{final_endpoint}label_matches={label_matches}"
+        if name:
+            final_endpoint = f"{final_endpoint}name={name}"
+
+
+        req = requests.get(final_endpoint, headers=self.headers)
+        if req.status_code == 200:
+            # json.loads returns it to a dictionary
+            req_dict = json.loads(req.text.encode('utf8'))
+            return req_dict
+
+        return req
+
+    def lock_resource(self, resource, signoff, link=None):
+        '''
+        Method that will lock the requested resource
+        :param resource: Resource to lock
+        :param signoff: A message to write when the requested resource
+            is about to lock
+        :return: Response after the PUT request
+        '''
+        lockable_resource = dict(resource)
+        lockable_resource['is_locked'] = True
+        lockable_resource['signoff'] = signoff
+        if link:
+            lockable_resource['link'] = link
+
+        final_endpoint = self.endpoints['resource'] + lockable_resource['name']
+        newjson = json.dumps(lockable_resource)
+
+        req = requests.put(final_endpoint, headers=self.headers, data=newjson)
+        return req
\ No newline at end of file
